@@ -258,10 +258,8 @@ impl<'a> PairPos2<'a> {
                 if let Some(pos) = self.get_by_classes(class1, class2) {
                     let all_zero = pos[0].map(|p| p.all_zero()).unwrap_or(true)
                         && pos[1].map(|p| p.all_zero()).unwrap_or(true);
-                    if !all_zero {
-                        if !f(glyph_id, next_id, pos) {
-                            return false;
-                        }
+                    if !all_zero && !f(glyph_id, next_id, pos) {
+                        return false;
                     }
                 }
                 true
@@ -281,10 +279,8 @@ impl<'a> PairPos2<'a> {
                 if let Some(pos) = self.get_by_classes(class1, class2) {
                     let all_zero = pos[0].map(|p| p.all_zero()).unwrap_or(true)
                         && pos[1].map(|p| p.all_zero()).unwrap_or(true);
-                    if !all_zero {
-                        if !f(class1, class2, pos) {
-                            return Some(false);
-                        }
+                    if !all_zero && !f(class1, class2, pos) {
+                        return Some(false);
                     }
                 }
             }
@@ -752,7 +748,7 @@ impl ValueFormat {
 /// Component of a value or anchor.
 #[derive(Copy, Clone, Default, Debug)]
 pub struct Component {
-    /// Raw value in font units.
+    /// Value in font units.
     pub value: FWord,
     /// Outer and inner indices for the item variation store.
     pub delta_indices: Option<[u16; 2]>,
@@ -772,7 +768,7 @@ impl Component {
     }
 }
 
-/// Raw value of a position adjustment in font units.
+/// Value of a position adjustment in font units.
 ///
 /// <https://docs.microsoft.com/en-us/typography/opentype/spec/gpos#value-record>
 #[derive(Copy, Clone, Default, Debug)]
@@ -822,7 +818,7 @@ impl core::fmt::Display for Value {
     }
 }
 
-/// Raw value of an anchor in font units.
+/// Value of an anchor in font units.
 ///
 /// <https://docs.microsoft.com/en-us/typography/opentype/spec/gpos#anchor-tables>
 #[derive(Copy, Clone, Default, Debug)]
@@ -842,8 +838,10 @@ impl<'a> Subtable<'a> {
         do_var: bool,
     ) -> Option<Value> {
         let d = self.data();
-        let mut pos = Value::default();
-        pos.format = format;
+        let mut pos = Value {
+            format,
+            ..Default::default()
+        };
         if format.0 == 4 {
             pos.x_advance.value = d.read_i16(offset)?;
             return Some(pos);
